ColVars Finder
==============

Find collective variables (CVs) of molecular systems by training neural networks.

Two methods are implemented by either training **autoencoder** or computing **eigenfunctions**.

See `Mathematical Backgrounds`_.

**This package is under development**.

Installation 
============

This package can be installed via `pip`:

.. code-block:: console

   pip install colvars-finder

Documentataion
==============

Please refer to `ColVars-Finder docs`_.

.. _`Mathematical Backgrounds`:
  https://colvars-finder.readthedocs.io/en/latest/math_backgrounds.html

.. _`ColVars-Finder docs`:
  https://colvars-finder.readthedocs.io/en/latest
